@@ -14,7 +14,7 @@ import sqlite3
 import shutil
 import time
 from datetime import datetime, timezone
-from typing import List, Dict, Optional, Tuple
+from typing import Any, List, Dict, Optional, Tuple
 from pathlib import Path
 import re
 
@@ -37,7 +37,7 @@ try:
 except (ImportError, ValueError) as e:
     # Handle both ImportError and ValueError (e.g., Keras compatibility issues)
     SEMANTIC_SEARCH_AVAILABLE = False
-    SemanticSearchEngine = None  # Define placeholder
+    SemanticSearchEngine = None  # type: ignore[misc,assignment]  # Placeholder when unavailable
     # Debug: Print error if verbose mode
     import os
 
@@ -81,9 +81,11 @@ class PlaybookManager:
                 self.db_path = Path(".claude/playbook.db")
             else:
                 self.db_path = Path(db_path)
-            self.playbook_path = (
-                self.db_path.parent / "playbook.json"
-            )  # For migration check only
+            # LEGACY: playbook.json path for migration support only.
+            # This allows users upgrading from older versions to have their
+            # playbook.json automatically migrated to playbook.db.
+            # DO NOT use playbook_path for new functionality.
+            self.playbook_path = self.db_path.parent / "playbook.json"
 
         # Check if DB exists, if not but JSON exists → migrate
         if not self.db_path.exists() and self.playbook_path.exists():
@@ -449,10 +451,17 @@ class PlaybookManager:
 
     def _migrate_json_to_sqlite(self) -> None:
         """
-        Migrate existing playbook.json to SQLite database.
+        LEGACY MIGRATION: Migrate existing playbook.json to SQLite database.
+
+        This method is intentionally preserved for backward compatibility.
+        It allows users upgrading from MAP Framework versions < 2.2 to have
+        their playbook.json automatically migrated to the new playbook.db format.
+
+        The references to playbook.json in this method are intentional and
+        should NOT be removed - they are part of the migration logic.
 
         Steps:
-        1. Load playbook.json
+        1. Load legacy playbook.json
         2. Create SQLite schema
         3. Insert all bullets into bullets table
         4. Insert metadata
@@ -565,7 +574,7 @@ class PlaybookManager:
 
         conn.close()
 
-        # Create backup of JSON
+        # Create backup of JSON and remove original
         backup_path = (
             str(self.playbook_path)
             + f".backup.{datetime.now(timezone.utc).strftime('%Y%m%d_%H%M%S')}"
@@ -578,6 +587,20 @@ class PlaybookManager:
         )
         print(f"✅ JSON backup saved to {backup_path}", file=sys.stderr)
 
+        # Remove original playbook.json to avoid confusion
+        # The backup is always available if needed
+        try:
+            self.playbook_path.unlink()
+            print(
+                f"✅ Removed {self.playbook_path} (backup preserved)",
+                file=sys.stderr,
+            )
+        except OSError as e:
+            print(
+                f"⚠️ Could not remove {self.playbook_path}: {e}",
+                file=sys.stderr,
+            )
+
     def _load_playbook_from_db(self) -> Dict:
         """Load playbook structure from SQLite database for backward compatibility."""
         cursor = self.db_conn.cursor()
@@ -599,7 +622,7 @@ class PlaybookManager:
         """
         )
 
-        sections = {}
+        sections: Dict[str, Dict[str, Any]] = {}
         # Initialize all standard sections
         for section_name in [
             "ARCHITECTURE_PATTERNS",
@@ -676,7 +699,12 @@ class PlaybookManager:
                 {"type": "UPDATE", "bullet_id": "sec-0012", "increment_helpful": 1}
             ]
         """
-        summary = {"added": 0, "updated": 0, "deprecated": 0, "errors": []}
+        summary: Dict[str, Any] = {
+            "added": 0,
+            "updated": 0,
+            "deprecated": 0,
+            "errors": [],
+        }
 
         for op in operations:
             try:
@@ -727,9 +755,9 @@ class PlaybookManager:
         section: str,
         content: str,
         code_example: Optional[str] = None,
-        related_to: List[str] = None,
-        tags: List[str] = None,
-        executable_scripts: List[str] = None,
+        related_to: Optional[List[str]] = None,
+        tags: Optional[List[str]] = None,
+        executable_scripts: Optional[List[str]] = None,
     ) -> str:
         """Add new bullet to section (saves to SQLite)."""
         if section not in self.playbook["sections"]:
@@ -903,34 +931,37 @@ class PlaybookManager:
         # Extract prefix from section name (first 4 chars, lowercase)
         prefix = re.sub(r"[^a-z]", "", section.lower())[:4]
 
-        # Find max existing ID number in section from SQLite (source of truth)
+        # Find max existing NUMERIC ID in section from SQLite
+        # Pattern: prefix-NNNN where NNNN is digits only
         cursor = self.db_conn.cursor()
         cursor.execute(
             """
             SELECT id FROM bullets
-            WHERE section = ? AND id LIKE ?
+            WHERE section = ? AND id GLOB ?
             ORDER BY id DESC LIMIT 1
         """,
-            (section, f"{prefix}-%"),
+            (section, f"{prefix}-[0-9][0-9][0-9][0-9]"),
         )
 
         result = cursor.fetchone()
         if result:
             # Extract number from ID like "impl-0042" -> 42
             last_id = result[0]
-            try:
-                last_num = int(last_id.split("-")[1])
-                next_num = last_num + 1
-            except (IndexError, ValueError):
-                # Fallback to count if ID format is unexpected
-                cursor.execute(
-                    "SELECT COUNT(*) FROM bullets WHERE section = ?", (section,)
-                )
-                next_num = cursor.fetchone()[0]
+            last_num = int(last_id.split("-")[1])
+            next_num = last_num + 1
         else:
+            # No numeric IDs found, start from 0
             next_num = 0
 
-        return f"{prefix}-{next_num:04d}"
+        # Ensure unique by checking if ID exists (handle gaps)
+        while True:
+            new_id = f"{prefix}-{next_num:04d}"
+            cursor.execute("SELECT 1 FROM bullets WHERE id = ?", (new_id,))
+            if not cursor.fetchone():
+                break
+            next_num += 1
+
+        return new_id
 
     def _deduplicate(self, threshold: float = 0.9) -> Dict:
         """
@@ -973,8 +1004,8 @@ class PlaybookManager:
 
             else:
                 # Fallback: exact content hash matching
-                seen_content = {}
-                to_remove = []
+                seen_content: Dict[str, int] = {}
+                to_remove: List[int] = []
 
                 for i, bullet in enumerate(bullets):
                     content_hash = hashlib.md5(bullet["content"].encode()).hexdigest()
@@ -1247,7 +1278,9 @@ class PlaybookManager:
             },
         )
 
-    def _build_fts_query(self, params: PlaybookQuery, limit: int) -> Tuple[str, List]:
+    def _build_fts_query(
+        self, params: PlaybookQuery, limit: int
+    ) -> Tuple[str, List[Any]]:
         """
         Build parameterized SQL query with FTS5 and filters.
 
@@ -1291,7 +1324,7 @@ class PlaybookManager:
             "JOIN bullets_fts fts ON b.rowid = fts.rowid",
             "WHERE fts.bullets_fts MATCH ?",
         ]
-        sql_params = [fts_query]
+        sql_params: List[Any] = [fts_query]
 
         # Section filter
         if params.sections:
@@ -1346,6 +1379,8 @@ class PlaybookManager:
         ]
 
         # Find semantically similar bullets
+        # Note: This method is only called when self.semantic_engine is not None
+        assert self.semantic_engine is not None, "semantic_engine must be available"
         similar_results = self.semantic_engine.find_similar(
             query=query,
             bullets=bullets,
